/*
******************************************************************************
*  Name     : FastBitmap.h
*  Date     : 3.8.04
*  Description:
*     A Class for storing bitmaps with alpha information.
*     
*  Copyright: Susi Games, Germany
******************************************************************************
*/

#ifndef __FASTBITMAP_H__
#define __FASTBITMAP_H__

#include <fbs.h>


/**
 * class CFastBitmap: A Class for storing bitmaps with alpha information.
 *
 * @author SusiGames.com
 */
class CFastBitmap: public CFbsBitmap
{
	
public:

	/**
	 * CFastBitmap: Standard constructor.
	 *
	 * @param aAlpahValues 1 for no Alpha, 2 for masked images, 4 for real alpha.
	 * @return 
	 */
	IMPORT_C CFastBitmap(TInt aAlpahValues);


	/**
	 * GetAlphaValues: 1(no alpha), 2(masked: on/off) or 4(real alpha) alpha values. 
	 *
	 * @return TInt 
	 */
	IMPORT_C TInt GetAlphaValues();


	/**
	 * IsMaskedImage: Returns ETrue if there is alpha information available for this image. 
	 *
	 * @return TBool 
	 */
	IMPORT_C TBool IsMaskedImage();


	/**
	 * GetFbsBitmap: Convert this bitmap to a standard CFbsBitmap.
	 *
	 * @return CFbsBitmap* 
	 */
	IMPORT_C CFbsBitmap* GetFbsBitmap();


	/**
	 * Lock: Locks the heap for this bitmap.
	 * So the OS cannot move the bitmap around, and the memory addresses stay valid until unlock()
	 * If accessing different bitmaps, be careful: They (probably) share one heap, so call Lock() only once...
	 *
	 * @return void 
	 */
	IMPORT_C void Lock();


	/**
	 * Unlock: To Unlock a locked heap.
	 *
	 * @return void 
	 */
	IMPORT_C void Unlock();

private:
	TBool iMaskedImage;
	TInt iAlphaValues;
};


#endif // __FASTBITMAP_H__

