/*
******************************************************************************
*  Name     : BitmapUtilsDemoEng.h
*  Date     : 30.7.04
*  Description:
*     A simple drawing engine, using DirectScreenAccess. 
*     
*  Copyright: Susi Games, Germany
******************************************************************************
*/

#ifndef BITMAPUTILSDEMOENG_H
#define BITMAPUTILSDEMOENG_H

#include <w32std.h>
#include "FastBitmap.h"
   
/**
 * class CBitmapUtilsDemoEng: A simple drawing engine, using DirectScreenAccess. 
 *
 * @author SusiGames.com
 */
class CBitmapUtilsDemoEng : public CTimer,	public MDirectScreenAccess	
	{

	public:
		void ChangeLoopInterval(TInt aAdd);
		void UpdatePositions();

		/**
		 * NewL: Standard NewL construction.
		 *
		 * @param aClient 
		 * @param aScreenDevice 
		 * @param aWindow 
		 * @return static CBitmapUtilsDemoEng* 
		 */
		static CBitmapUtilsDemoEng* NewL 
			(RWsSession& aClient, CWsScreenDevice& aScreenDevice, RWindow& aWindow);

		/**
		 * ~CBitmapUtilsDemoEng: Destructor.
		 *
		 * @return  
		 */
		~CBitmapUtilsDemoEng();	

		void SetForegroundBitmaps(CFastBitmap* aBmp1,CFastBitmap* aBmp2);
		void SetBackgroundImage(CFastBitmap* aImage);


		/**
		 * StartDrawingL: Start drawing.
		 *
		 * @return void 
		 */
		void StartDrawingL();


		/**
		 * StopDrawing: Stop drawing.
		 *
		 * @return void 
		 */
		void StopDrawing();


		/**
		 * Drawing: ETrue if the engine is drawing.
		 *
		 * @return inline TBool 
		 */
		inline TBool Drawing(){return iDrawing;}


	private:

		/**
		 * Restart: From MDirectScreenAccess.
		 *
		 * @param aReason 
		 * @return void 
		 */
		void Restart(RDirectScreenAccess::TTerminationReasons aReason);


		/**
		 * AbortNow: From MDirectScreenAccess.
		 *
		 * @param aReason 
		 * @return void 
		 */
		void AbortNow(RDirectScreenAccess::TTerminationReasons aReason);


		/**
		 * RunL: From CTimer.
		 *
		 * @return void 
		 */
		void RunL();


		/**
		 * DoCancel: From CTimer.
		 *
		 * @return void 
		 */
		void DoCancel();


		/**
		 * CBitmapUtilsDemoEng: Constructor.
		 *
		 * @param aClient 
		 * @param aScreenDevice 
		 * @param aWindow 
		 * @return  
		 */
		CBitmapUtilsDemoEng
			(RWsSession& aClient,CWsScreenDevice& aScreenDevice,RWindow& aWindow);

		/**
		 * ConstructL: Standard two-phase construction.
		 *
		 * @return void 
		 */
		void ConstructL();	


	private:

		// Window server handling
		RWsSession& iClient;
		CWsScreenDevice& iScreenDevice;
		RWindow& iWindow;

		// Direct Screen Access
		CDirectScreenAccess* iDirectScreenAccess;
		CFbsBitGc* iGc;
		RRegion* iRegion;

		TPoint iPosition;	

		// ETrue if engine draws to screen
		TBool iDrawing;

		// EFalse if running on emulator
		TBool iUseFrameBuffer;

		// adress of framebuffer
		TUint8* iScreenAddr;

		// bitmap for offscreen drawing
		CFastBitmap* iOffScreenBmp;

		// the drawing region
		TRect iDrawRect;

		// length of the frame buffer
		TInt  iFrameBufLen;
    
		// raw event for forcing the update of screen
		TRawEvent iRedraw; 

		CFastBitmap* iBackground;
		CFastBitmap *iBmp1,*iBmp2;

		TPoint iPos1;
		TInt iStep1_x,iStep1_y;
		TPoint iPos2;
		TInt iStep2_x,iStep2_y;

		// screen size:
		TInt iWidth,iHeight;

		TInt iLoopInterval;
	};

#endif

// End of File

